@@ -51,7 +51,6 @@ def amz_gen_init(verbose=False):
         amz_user_config['amz_tool_meta']['user'] = getpass.getuser()
         with open(f'{AMZ_CONFIG_DIR}/amz-config.yaml', 'w') as f:
             yaml.dump(amz_user_config, f)
-            f.close()
         meta.update_line_in_file('export AMZ_DATA=', f"export AMZ_DATA={AMZ_DATA_DIR}",
                                  f"{AMZ_CONFIG_DIR}/amz_source.sh")
         meta.update_line_in_file('export AMZ_CONFIG=', f"export AMZ_CONFIG={AMZ_CONFIG_DIR}",
@@ -65,11 +64,7 @@ def amz_gen_init(verbose=False):
 
     # Turn paths to custom githooks into absolute paths
     try:
-        with open(f'{AMZ_DATA_DIR}/githooks/config/.pre-commit-config.yaml', 'r') as file:
-            filedata = file.read()
-        filedata = filedata.replace('AMZ_DATA_DIR', AMZ_DATA_DIR)
-        with open(f'{AMZ_DATA_DIR}/githooks/config/.pre-commit-config.yaml', 'w') as file:
-            file.write(filedata)
+        meta.substitute_in_file('AMZ_DATA_DIR', AMZ_DATA_DIR, f'{AMZ_DATA_DIR}/githooks/config/.pre-commit-config.yaml')
     except:
         l.end(1)
 
@@ -91,7 +86,6 @@ def amz_gen_init(verbose=False):
         if not BASHRC_LINE_EXISTS:
             with open(f"{HOME_DIR}/.bashrc", 'a') as f:
                 f.write("\n# AMZ Tool Helper \nsource ~/.amz/config/amz_source.sh\n")
-                f.close()
     except:
         l.end(1)
 
@@ -106,6 +100,26 @@ def amz_gen_init(verbose=False):
     except:
         l.end(1)
 
+    # Setting up auto-updater
+    if not os.path.exists('/etc/systemd/system/amz_updater.timer'):
+        l.chain("Setting up amz updater", "\t", 0)
+        try:
+            # Replace user var
+            meta.substitute_in_file('__USER__', getpass.getuser(), f'{AMZ_DATA_DIR}/auto_update/amz_updater.service')
+            # Copy files and reload systemd daemon
+            p1 = sp.run(
+                f'sudo cp {AMZ_DATA_DIR}/auto_update/amz_updater* /etc/systemd/system/ && sudo systemctl daemon-reload',
+                shell=True,
+                stdout=sp.PIPE if not verbose else None,
+                stderr=sp.PIPE if not verbose else None)
+            p2 = sp.run('sudo systemctl enable amz_updater.timer && sudo systemctl restart amz_updater.timer',
+                        shell=True,
+                        stdout=sp.PIPE if not verbose else None,
+                        stderr=sp.PIPE if not verbose else None)
+            l.end(p1.returncode + p2.returncode)
+        except:
+            l.end(1)
+
     # Termination point
     l.end(0)
 
@@ -175,7 +189,6 @@ def amz_repo_init(verbose=False):
                     amz_user_config['amz_tool_meta']['repos'].append(amz_root_dir)
             with open(f'{AMZ_CONFIG_DIR}/amz-config.yaml', 'w') as f:
                 yaml.dump(amz_user_config, f)
-                f.close()
         except:
             print("Some issue with data files... Run `amz init gen` again. ")
             l.end(1)
@@ -195,7 +208,6 @@ def amz_repo_init(verbose=False):
                     amz_user_config['amz_tool_meta']['repos'].append(amz_root_dir)
             with open(f'{AMZ_CONFIG_DIR}/amz-config.yaml', 'w') as f:
                 yaml.dump(amz_user_config, f)
-                f.close()
         except:
             print("Some issue with data files... Run `amz init gen` again. ")
             l.end(1)
@@ -278,3 +290,29 @@ def amz_repo_init(verbose=False):
         l.end(1)
 
     return
+
+
+# Concise init function after update
+def amz_update_init() -> bool:
+
+    # Copy Data
+    try:
+        # Copy data into .amz dir
+        copy_tree(f'{PKG_DIR}/data', AMZ_DATA_DIR)
+        # Update vars in pre-commit yaml config
+        meta.substitute_in_file('AMZ_DATA_DIR', AMZ_DATA_DIR, f'{AMZ_DATA_DIR}/githooks/config/.pre-commit-config.yaml')
+    except:
+        return False
+
+    # For repo in amz repos, copy config files
+    try:
+        # Fetch all AMZ Repos
+        amz_repos = meta.get_amz_config(['amz_tool_meta', 'repos'])
+
+        for repo in amz_repos:
+            # Copy config files to root of repo: pre-commit, clang-format, yapf, cpplint, and pylint
+            copy_tree(f'{AMZ_DATA_DIR}/githooks/config/', repo)
+    except:
+        return False
+
+    return True
